@@ -161,7 +161,7 @@ __DATA__
 do{ my $x = [
        {
          'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/local/include -I/usr/include',
-         'additional_libs' => '-L/usr/lib -L/usr/local/lib -Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib',
+         'additional_libs' => '-L/usr/local/lib -Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib -L/usr/lib',
          'build_arch' => 'armv5tel-linux-thread-multi',
          'build_cc' => 'cc',
          'build_os' => 'linux',
